#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: sites_dns_settings
short_description: Resource module for Sites Dns Settings
description:
  - Manage operation update of the resource Sites Dns Settings. - > Set DNS settings for a site; `null` values indicate that
    the setting will be inherited from the parent site; empty objects `{}` indicate that the settings is unset.
version_added: '6.15.0'
extends_documentation_fragment:
  - cisco.dnac.module
author: Rafael Campos (@racampos)
options:
  dns:
    description: Sites Dns Settings's dns.
    suboptions:
      dnsServers:
        description: DNS servers for hostname resolution.
        elements: str
        type: list
      domainName:
        description: Network's domain name. Example myCompnay.com.
        type: str
    type: dict
  id:
    description: Id path parameter. Site Id.
    type: str
requirements:
  - dnacentersdk >= 2.11.0
  - python >= 3.12
seealso:
  - name: Cisco DNA Center documentation for Network Settings SetDNSSettingsForASite
    description: Complete reference of the SetDNSSettingsForASite API.
    link: https://developer.cisco.com/docs/dna-center/#!set-dns-settings-for-a-site
notes:
  - SDK Method used are
    network_settings.NetworkSettings.set_d_n_s_settings_for_a_site,
  - Paths used are
    put /dna/intent/api/v1/sites/{id}/dnsSettings,
"""

EXAMPLES = r"""
---
- name: Update all
  cisco.dnac.sites_dns_settings:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    state: present
    dns:
      dnsServers:
        - string
      domainName: string
    id: string
"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {
      "version": "string",
      "response": {
        "count": 0
      }
    }
"""



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: transit_network_health_summaries_info
short_description: Information module for Transit Network Health Summaries
description:
  - Get all Transit Network Health Summaries.
  - Get Transit Network Health Summaries by id.
  - Get a paginated list of Transit Networks with health summary.
  - Get health summary for a specific transit Network by providing the unique transit networks id in the url path.
version_added: '6.17.0'
extends_documentation_fragment:
  - cisco.dnac.module_info
author: Rafael Campos (@racampos)
options:
  headers:
    description: Additional headers.
    type: dict
  startTime:
    description:
      - >
        StartTime query parameter. Start time from which API queries the data set related to the resource. It
        must be specified in UNIX epochtime in milliseconds. Value is inclusive.
    type: float
  endTime:
    description:
      - >
        EndTime query parameter. End time to which API queries the data set related to the resource. It must be
        specified in UNIX epochtime in milliseconds. Value is inclusive.
    type: float
  limit:
    description:
      - Limit query parameter. Maximum number of records to return.
    type: int
  offset:
    description:
      - >
        Offset query parameter. Specifies the starting point within all records returned by the API. It's one
        based offset. The starting value is 1.
    type: int
  sortBy:
    description:
      - SortBy query parameter. A field within the response to sort by.
    type: str
  order:
    description:
      - Order query parameter. The sort order of the field ascending or descending.
    type: str
  id:
    description:
      - >
        Id query parameter. The list of transit entity ids. (Ex "1551156a-bc97-3c63-aeda-8a6d3765b5b9") Examples
        id=1551156a-bc97-3c63-aeda-8a6d3765b5b9 (single entity uuid requested)
        id=1551156a-bc97-3c63-aeda-8a6d3765b5b9&id=4aa20652-237c-4625-b2b4-fd7e82b6a81e (multiple entity uuids
        with '&' separator).
    type: str
  attribute:
    description:
      - Attribute query parameter. The interested fields in the request. For valid attributes, verify the documentation.
    type: str
  view:
    description:
      - >
        View query parameter. The specific summary view being requested. This is an optional parameter which can
        be passed to get one or more of the specific health data summaries associated with sites.
    type: str
requirements:
  - dnacentersdk >= 2.11.0
  - python >= 3.12
seealso:
  - name: Cisco DNA Center documentation for SDA ReadListOfTransitNetworksWithTheirHealthSummary
    description: Complete reference of the ReadListOfTransitNetworksWithTheirHealthSummary API.
    link: https://developer.cisco.com/docs/dna-center/#!read-list-of-transit-networks-with-their-health-summary
  - name: Cisco DNA Center documentation for SDA ReadTransitNetworkWithItsHealthSummaryFromId
    description: Complete reference of the ReadTransitNetworkWithItsHealthSummaryFromId API.
    link: https://developer.cisco.com/docs/dna-center/#!read-transit-network-with-its-health-summary-from-id
notes:
  - SDK Method used are
    sda.Sda.read_list_of_transit_networks_with_their_health_summary,
    sda.Sda.read_transit_network_with_its_health_summary_from_id,
  - Paths used are
    get /dna/data/api/v1/transitNetworkHealthSummaries,
    get /dna/data/api/v1/transitNetworkHealthSummaries/{id},
"""

EXAMPLES = r"""
---
- name: Get all Transit Network Health Summaries
  cisco.dnac.transit_network_health_summaries_info:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    headers: "{{my_headers | from_json}}"
    startTime: 0
    endTime: 0
    limit: 0
    offset: 0
    sortBy: string
    order: string
    id: string
    attribute: string
    view: string
  register: result
- name: Get Transit Network Health Summaries by id
  cisco.dnac.transit_network_health_summaries_info:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    headers: "{{my_headers | from_json}}"
    endTime: 0
    startTime: 0
    attribute: string
    view: string
    id: string
  register: result
"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {
      "response": {
        "id": "string",
        "name": "string",
        "controlPlaneCount": 0,
        "transitType": [
          "string"
        ],
        "networkProtocol": "string",
        "fabricSitesCount": 0,
        "goodHealthPercentage": 0,
        "goodHealthDeviceCount": 0,
        "totalHealthDeviceCount": 0,
        "poorHealthDeviceCount": 0,
        "fairHealthDeviceCount": 0,
        "transitControlPlaneHealthPercentage": 0,
        "transitControlPlaneTotalDeviceCount": 0,
        "transitControlPlaneGoodHealthDeviceCount": 0,
        "transitControlPlanePoorHealthDeviceCount": 0,
        "transitControlPlaneFairHealthDeviceCount": 0,
        "transitServicesHealthPercentage": 0,
        "transitServicesTotalDeviceCount": 0,
        "transitServicesGoodHealthDeviceCount": 0,
        "transitServicesPoorHealthDeviceCount": 0,
        "transitServicesFairHealthDeviceCount": 0,
        "pubsubTransitHealthPercentage": 0,
        "pubsubTransitTotalDeviceCount": 0,
        "pubsubTransitGoodHealthDeviceCount": 0,
        "pubsubTransitPoorHealthDeviceCount": 0,
        "pubsubTransitFairHealthDeviceCount": 0,
        "lispTransitHealthPercentage": 0,
        "lispTransitTotalDeviceCount": 0,
        "lispTransitGoodHealthDeviceCount": 0,
        "lispTransitPoorHealthDeviceCount": 0,
        "lispTransitFairHealthDeviceCount": 0,
        "internetAvailTransitHealthPercentage": 0,
        "internetAvailTransitTotalDeviceCount": 0,
        "internetAvailTransitGoodHealthDeviceCount": 0,
        "internetAvailTransitPoorHealthDeviceCount": 0,
        "internetAvailTransitFairHealthDeviceCount": 0,
        "bgpTcpHealthPercentage": 0,
        "bgpTcpTotalDeviceCount": 0,
        "bgpTcpGoodHealthDeviceCount": 0,
        "bgpTcpPoorHealthDeviceCount": 0,
        "bgpTcpFairHealthDeviceCount": 0,
        "siteHierarchy": "string",
        "siteHierarchyId": "string"
      },
      "version": "string"
    }
"""



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: wireless_profiles_info
short_description: Information module for Wireless Profiles
description:
  - Get all Wireless Profiles.
  - Get Wireless Profiles by id.
  - This API allows the user to get a Wireless Network Profile by ID.
  - This API allows the user to get all Wireless Network Profiles.
version_added: '6.15.0'
extends_documentation_fragment:
  - cisco.dnac.module_info
author: Rafael Campos (@racampos)
options:
  headers:
    description: Additional headers.
    type: dict
  limit:
    description:
      - >
        Limit query parameter. The number of records to show for this page. Default is 500 if not specified.
        Maximum allowed limit is 500.
    type: int
  offset:
    description:
      - Offset query parameter. The first record to show for this page; the first record is numbered 1.
    type: int
  wirelessProfileName:
    description:
      - WirelessProfileName query parameter. Wireless Profile Name.
    type: str
  id:
    description:
      - Id path parameter. Wireless Profile Id.
    type: str
requirements:
  - dnacentersdk >= 2.11.0
  - python >= 3.12
seealso:
  - name: Cisco DNA Center documentation for Wireless GetWirelessProfileByID
    description: Complete reference of the GetWirelessProfileByID API.
    link: https://developer.cisco.com/docs/dna-center/#!get-wireless-profile-by-id
  - name: Cisco DNA Center documentation for Wireless GetWirelessProfiles
    description: Complete reference of the GetWirelessProfiles API.
    link: https://developer.cisco.com/docs/dna-center/#!get-wireless-profiles
notes:
  - SDK Method used are
    wireless.Wireless.get_wireless_profile_by_id,
    wireless.Wireless.get_wireless_profiles,
  - Paths used are
    get /dna/intent/api/v1/wirelessProfiles,
    get /dna/intent/api/v1/wirelessProfiles/{id},
"""

EXAMPLES = r"""
---
- name: Get all Wireless Profiles
  cisco.dnac.wireless_profiles_info:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    headers: "{{my_headers | from_json}}"
    limit: 0
    offset: 0
    wirelessProfileName: string
  register: result
- name: Get Wireless Profiles by id
  cisco.dnac.wireless_profiles_info:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    headers: "{{my_headers | from_json}}"
    id: string
  register: result
"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {
      "response": [
        {
          "wirelessProfileName": "string",
          "ssidDetails": [
            {
              "ssidName": "string",
              "flexConnect": {
                "enableFlexConnect": true,
                "localToVlan": 0
              },
              "enableFabric": true,
              "wlanProfileName": "string",
              "interfaceName": "string",
              "policyProfileName": "string",
              "dot11beProfileId": "string",
              "anchorGroupName": "string",
              "vlanGroupName": "string"
            }
          ],
          "id": "string",
          "additionalInterfaces": [
            "string"
          ],
          "apZones": [
            {
              "apZoneName": "string",
              "rfProfileName": "string",
              "ssids": [
                "string"
              ]
            }
          ],
          "featureTemplates": [
            {
              "id": "string",
              "ssids": [
                "string"
              ]
            }
          ]
        }
      ],
      "version": "string"
    }
"""



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: energy_sites_count_info
short_description: Information module for Energy Sites Count
description:
  - Get all Energy Sites Count. - > Retrieves the total count of sites that provide energy data, filtered according to the
    specified query parameters. For detailed information about the usage of the API, please refer to the Open API specification
    document - https //github.com/cisco-en-programmability/catalyst-center-api- specs/blob/main/Assurance/CE_Cat_Center_Org-sitesEnergy-1.0.1-resolved.yaml.
version_added: '6.18.0'
extends_documentation_fragment:
  - cisco.dnac.module_info
author: Rafael Campos (@racampos)
options:
  headers:
    description: Additional headers.
    type: dict
  startTime:
    description:
      - >
        StartTime query parameter. Start time from which API queries the data set related to the resource. It
        must be specified in UNIX epochtime in milliseconds. Value is inclusive. If `startTime` is not provided,
        API will default to one day before `endTime`.
    type: float
  endTime:
    description:
      - >
        EndTime query parameter. End time to which API queries the data set related to the resource. It must be
        specified in UNIX epochtime in milliseconds. Value is inclusive. If `endTime` is not provided, API will
        default to one day after `startTime`. If `startTime` is not provided either, API will default to current
        time.
    type: float
  siteHierarchy:
    description:
      - >
        SiteHierarchy query parameter. The full hierarchical breakdown of the site tree starting from Global
        site name and ending with the specific site name. The Root site is named "Global" (Ex.
        `Global/AreaName/BuildingName/FloorName`) This field supports wildcard asterisk (`*`) character search
        support. E.g. `*/San*, */San, /San*` Examples `?siteHierarchy=Global/AreaName/BuildingName/FloorName`
        (single siteHierarchy requested) `?siteHierarchy=Global/AreaName/BuildingName/FloorName&siteHierarchy=Gl
        obal/AreaName2/BuildingName2/FloorName2` (multiple siteHierarchies requested).
    type: str
  siteHierarchyId:
    description:
      - >
        SiteHierarchyId query parameter. The full hierarchy breakdown of the site tree in id form starting from
        Global site UUID and ending with the specific site UUID. (Ex.
        `globalUuid/areaUuid/buildingUuid/floorUuid`) This field supports wildcard asterisk (`*`) character
        search support. E.g. `*uuid*, *uuid, uuid*` Examples
        `?siteHierarchyId=globalUuid/areaUuid/buildingUuid/floorUuid `(single siteHierarchyId requested) `?siteH
        ierarchyId=globalUuid/areaUuid/buildingUuid/floorUuid&siteHierarchyId=globalUuid/areaUuid2/buildingUuid2
        /floorUuid2` (multiple siteHierarchyIds requested).
    type: str
  siteName:
    description:
      - >
        SiteName query parameter. The name of the site. (Ex. `FloorName`) This field supports wildcard asterisk
        (`*`) character search support. E.g. `*San*, *San, San*` Examples `?siteName=building1` (single siteName
        requested) `?siteName=building1&siteName=building2&siteName=building3` (multiple siteNames requested).
    type: str
  siteType:
    description:
      - >
        SiteType query parameter. The type of the site. A site can be an area, building, or floor. Default when
        not provided will be `floor,building,area` Examples `?siteType=area` (single siteType requested)
        `?siteType=area&siteType=building&siteType=floor` (multiple siteTypes requested).
    type: str
  deviceCategory:
    description:
      - >
        DeviceCategory query parameter. The list of device categories. Note that this filter specifies which
        devices will be included when calculating energy consumption values, rather than specifying the list of
        returned sites. Examples `deviceCategory=Switch` (single device category requested)
        `deviceCategory=Switch&deviceCategory=Router` (multiple device categories with comma separator).
    type: str
  siteId:
    description:
      - >
        SiteId query parameter. The UUID of the site. (Ex. `flooruuid`) Examples `?siteId=id1` (single id
        requested) `?siteId=id1&siteId=id2&siteId=id3` (multiple ids requested).
    type: str
  taskId:
    description:
      - >
        TaskId query parameter. Used to retrieve asynchronously processed & stored data. When this parameter is
        used, the rest of the request params will be ignored.
    type: str
requirements:
  - dnacentersdk >= 2.11.0
  - python >= 3.12
seealso:
  - name: Cisco DNA Center documentation for Sites CountSitesEnergy
    description: Complete reference of the CountSitesEnergy API.
    link: https://developer.cisco.com/docs/dna-center/#!count-sites-energy
notes:
  - SDK Method used are
    sites.Sites.count_sites_energy,
  - Paths used are
    get /dna/data/api/v1/energy/sites/count,
"""

EXAMPLES = r"""
---
- name: Get all Energy Sites Count
  cisco.dnac.energy_sites_count_info:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    headers: "{{my_headers | from_json}}"
    startTime: 0
    endTime: 0
    siteHierarchy: string
    siteHierarchyId: string
    siteName: string
    siteType: string
    deviceCategory: string
    siteId: string
    taskId: string
  register: result
"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {
      "response": {
        "count": 0
      },
      "version": "string"
    }
"""



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: roles_v2_info
short_description: Information module for Roles V2
description:
  - Get all Roles V2.
  - Get Roles V2 by id.
  - Get a role in the system v2-.
  - Get all roles in the system v2-.
version_added: '6.46.0'
extends_documentation_fragment:
  - cisco.dnac.module_info
author: Rafael Campos (@racampos)
options:
  headers:
    description: Additional headers.
    type: dict
  id:
    description:
      - Id path parameter. Id of the role to look up.
    type: str
requirements:
  - dnacentersdk >= 2.11.0
  - python >= 3.12
seealso:
  - name: Cisco DNA Center documentation for User and Roles GetRoleV2
    description: Complete reference of the GetRoleV2 API.
    link: https://developer.cisco.com/docs/dna-center/#!get-role-v-2
  - name: Cisco DNA Center documentation for User and Roles GetRolesV2
    description: Complete reference of the GetRolesV2 API.
    link: https://developer.cisco.com/docs/dna-center/#!get-roles-v-2
notes:
  - SDK Method used are
    userand_roles.UserandRoles.get_role_v2,
    userand_roles.UserandRoles.get_roles_v2,
  - Paths used are
    get /dna/system/api/v2/roles,
    get /dna/system/api/v2/roles/{id},
"""

EXAMPLES = r"""
---
- name: Get all Roles V2
  cisco.dnac.roles_v2_info:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    headers: "{{my_headers | from_json}}"
  register: result
- name: Get Roles V2 by id
  cisco.dnac.roles_v2_info:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    headers: "{{my_headers | from_json}}"
    id: string
  register: result
"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {
      "id": "string",
      "name": "string",
      "description": "string",
      "permissions": [
        {
          "privilege": "string",
          "id": "string"
        }
      ],
      "type": "string",
      "version": "string",
      "meta": {
        "created": "string",
        "createdBy": "string",
        "lastModified": "string",
        "lastModifiedBy": "string"
      }
    }
"""



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: filter_group_aassociations_delete
short_description: Resource module for Filter Group Aassociations Delete
description:
  - Manage operation delete of the resource Filter Group Aassociations Delete. - > Deletes the association between filter
    group and entity. For detailed information about the usage of the API, please refer to the Open API specification document
    - https //github.com/cisco-en-programmability/catalyst- center-api-specs/blob/main/Assurance/CE_Cat_Center_Org-FilterGroups-1.0.0-resolved.yaml.
version_added: '6.46.0'
extends_documentation_fragment:
  - cisco.dnac.module
author: Rafael Campos (@racampos)
options:
  headers:
    description: Additional headers.
    type: dict
  id:
    description: Id path parameter. Association id.
    type: str
requirements:
  - dnacentersdk >= 2.11.0
  - python >= 3.12
seealso:
  - name: Cisco DNA Center documentation for Devices DeleteFilterGroupAssociation
    description: Complete reference of the DeleteFilterGroupAssociation API.
    link: https://developer.cisco.com/docs/dna-center/#!delete-filter-group-association
notes:
  - SDK Method used are
    devices.Devices.delete_filter_group_association,
  - Paths used are
    delete /dna/intent/api/v1/filterGroupAassociations/{id},
"""

EXAMPLES = r"""
---
- name: Delete by id
  cisco.dnac.filter_group_aassociations_delete:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    headers: '{{my_headers | from_json}}'
    id: string
"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {}
"""



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: network_applications_info
short_description: Information module for Network Applications
description:
  - Get all Network Applications.
  - Retrieves the list of network applications along with experience and health metrics.
  - If startTime and endTime are not provided, the API defaults to the last 24 hours.
  - siteId is mandatory. siteId must be a site UUID of a building.
  - For detailed information about the usage of the API, please refer to the Open API specification document.
    https //github.com/cisco-en-programmability/catalyst-center-api-specs/blob/main/Assurance/CE_Cat_Center_Org-NetworkApplications-1.0.0-resolved.yaml.
version_added: '6.17.0'
extends_documentation_fragment:
  - cisco.dnac.module_info
author: Rafael Campos (@racampos)
options:
  headers:
    description: Additional headers.
    type: dict
  startTime:
    description:
      - >
        StartTime query parameter. Start time from which API queries the data set related to the resource. It
        must be specified in UNIX epochtime in milliseconds. Value is inclusive.
    type: float
  endTime:
    description:
      - >
        EndTime query parameter. End time to which API queries the data set related to the resource. It must be
        specified in UNIX epochtime in milliseconds. Value is inclusive.
    type: float
  limit:
    description:
      - Limit query parameter. Maximum number of records to return.
    type: int
  offset:
    description:
      - >
        Offset query parameter. Specifies the starting point within all records returned by the API. It's one
        based offset. The starting value is 1.
    type: int
  sortBy:
    description:
      - SortBy query parameter. A field within the response to sort by.
    type: str
  order:
    description:
      - Order query parameter. The sort order of the field ascending or descending.
    type: str
  siteId:
    description:
      - >
        SiteId query parameter. The site UUID without the top level hierarchy. `siteId` is mandatory. `siteId`
        must be a site UUID of a building. (Ex."buildingUuid") Examples `siteId=buildingUuid` (single siteId
        requested) `siteId=buildingUuid1&siteId=buildingUuid2` (multiple siteId requested).
    type: str
  ssid:
    description:
      - >
        Ssid query parameter. In the context of a network application, SSID refers to the name of the wireless
        network to which the client connects. Examples `ssid=Alpha` (single ssid requested)
        `ssid=Alpha&ssid=Guest` (multiple ssid requested).
    type: str
  applicationName:
    description:
      - >
        ApplicationName query parameter. Name of the application for which the experience data is intended.
        Examples `applicationName=webex` (single applicationName requested)
        `applicationName=webex&applicationName=teams` (multiple applicationName requested).
    type: str
  businessRelevance:
    description:
      - >
        BusinessRelevance query parameter. The application can be chosen to be categorized as business-relevant,
        irrelevant, or default (neutral). By doing so, the assurance application prioritizes the monitoring and
        analysis of business-relevant data, ensuring critical insights are captured. Applications marked as
        irrelevant or default are selectively excluded from certain data sets, streamlining focus on what's most
        important for business outcomes.
    type: str
  attribute:
    description:
      - >
        Attribute query parameter. List of attributes related to resource that can be requested to only be part
        of the response along with the required attributes. Supported attributes are applicationName, siteId,
        exporterIpAddress, exporterNetworkDeviceId, healthScore, businessRelevance, usage, throughput,
        packetLossPercent, networkLatency, applicationServerLatency, clientNetworkLatency, serverNetworkLatency,
        trafficClass, jitter, ssid Examples `attribute=healthScore` (single attribute requested)
        `attribute=healthScore&attribute=ssid&attribute=jitter` (multiple attribute requested).
    type: str
requirements:
  - dnacentersdk >= 2.11.0
  - python >= 3.12
seealso:
  - name: Cisco DNA Center documentation for Applications RetrievesTheListOfNetworkApplicationsAlongWithExperienceAndHealthMetrics
    description: Complete reference of the RetrievesTheListOfNetworkApplicationsAlongWithExperienceAndHealthMetrics API.
    link: https://developer.cisco.com/docs/dna-center/#!retrieves-the-list-of-network-applications-along-with-experience-and-health-metrics
notes:
  - SDK Method used are
    applications.Applications.retrieves_the_list_of_network_applications_along_with_experience_and_health_metrics,
  - Paths used are
    get /dna/data/api/v1/networkApplications,
"""

EXAMPLES = r"""
---
- name: Get all Network Applications
  cisco.dnac.network_applications_info:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    headers: "{{my_headers | from_json}}"
    startTime: 0
    endTime: 0
    limit: 0
    offset: 0
    sortBy: string
    order: string
    siteId: string
    ssid: string
    applicationName: string
    businessRelevance: string
    attribute: string
  register: result
"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {
      "response": [
        {
          "id": "string",
          "applicationName": "string",
          "businessRelevance": "string",
          "siteId": "string",
          "exporterIpAddress": "string",
          "exporterNetworkDeviceId": "string",
          "healthScore": 0,
          "usage": 0,
          "throughput": 0,
          "packetLossPercent": 0,
          "networkLatency": 0,
          "applicationServerLatency": 0,
          "clientNetworkLatency": 0,
          "serverNetworkLatency": 0,
          "trafficClass": "string",
          "jitter": 0,
          "ssid": "string"
        }
      ],
      "page": {
        "limit": 0,
        "offset": 0,
        "count": 0,
        "sortBy": [
          {
            "name": "string",
            "order": "string"
          }
        ]
      },
      "version": "string"
    }
"""



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: wireless_settings_interfaces
short_description: Resource module for Wireless Settings Interfaces
description:
  - Manage operations create, update and delete of the resource Wireless Settings Interfaces.
  - This API allows the user to create an interface.
  - This API allows the user to delete an interface by ID.
  - This API allows the user to update an interface by ID.
version_added: '6.15.0'
extends_documentation_fragment:
  - cisco.dnac.module
author: Rafael Campos (@racampos)
options:
  id:
    description: Id path parameter. Interface ID.
    type: str
  interfaceName:
    description: Interface Name.
    type: str
  vlanId:
    description: VLAN ID range is 1-4094.
    type: int
requirements:
  - dnacentersdk >= 2.11.0
  - python >= 3.12
seealso:
  - name: Cisco DNA Center documentation for Wireless CreateInterface
    description: Complete reference of the CreateInterface API.
    link: https://developer.cisco.com/docs/dna-center/#!create-interface
  - name: Cisco DNA Center documentation for Wireless DeleteInterface
    description: Complete reference of the DeleteInterface API.
    link: https://developer.cisco.com/docs/dna-center/#!delete-interface
  - name: Cisco DNA Center documentation for Wireless UpdateInterface
    description: Complete reference of the UpdateInterface API.
    link: https://developer.cisco.com/docs/dna-center/#!update-interface
notes:
  - SDK Method used are
    wireless.Wireless.create_interface,
    wireless.Wireless.delete_interface,
    wireless.Wireless.update_interface,
  - Paths used are
    post /dna/intent/api/v1/wirelessSettings/interfaces,
    delete /dna/intent/api/v1/wirelessSettings/interfaces/{id},
    put /dna/intent/api/v1/wirelessSettings/interfaces/{id},
"""

EXAMPLES = r"""
---
- name: Create
  cisco.dnac.wireless_settings_interfaces:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    state: present
    interfaceName: string
    vlanId: 0
- name: Delete by id
  cisco.dnac.wireless_settings_interfaces:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    state: absent
    id: string
- name: Update by id
  cisco.dnac.wireless_settings_interfaces:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    state: present
    id: string
    interfaceName: string
    vlanId: 0
"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {
      "response": {
        "taskId": "string",
        "url": "string"
      },
      "version": "string"
    }
"""



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: system_settings_ap_pnp_location
short_description: Resource module for System Settings Ap Pnp Location
description:
  - Manage operation update of the resource System Settings Ap Pnp Location. - > Enable or disable the AP PnP Location setting
    in the system.Once the AP PnP Location Setting is enabled, the Access Point's assigned Site name will be configured as
    the AP Location during the PnP Claim process. This applies only during the PnP onboarding process and not during any subsequent
    provisioning dayN .
version_added: '6.18.0'
extends_documentation_fragment:
  - cisco.dnac.module
author: Rafael Campos (@racampos)
options:
  apPnPLocation:
    description: Enable Or Disable.Once the AP PnP Location Setting is enabled, the Access Point's assigned Site name will
      be configured as the AP Location during the PnP Claim process. This applies only during the PnP onboarding process and
      not during any subsequent provisioning (dayN).
    type: str
requirements:
  - dnacentersdk >= 2.11.0
  - python >= 3.12
seealso:
  - name: Cisco DNA Center documentation for Wireless UpdateAPPnPLocationSetting
    description: Complete reference of the UpdateAPPnPLocationSetting API.
    link: https://developer.cisco.com/docs/dna-center/#!update-ap-pn-p-location-setting
notes:
  - SDK Method used are
    wireless.Wireless.update_ap_pnp_location_setting,
  - Paths used are
    put /dna/intent/api/v1/systemSettings/apPnpLocation,
"""

EXAMPLES = r"""
---
- name: Update all
  cisco.dnac.system_settings_ap_pnp_location:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    state: present
    apPnPLocation: string
"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {
      "response": {
        "taskId": "string",
        "url": "string"
      },
      "version": "string"
    }
"""



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: backup_restore_executions_info
short_description: Information module for Backup Restore Executions
description:
  - Get all Backup Restore Executions.
  - Get Backup Restore Executions by id.
  - This api is used to get all the backup and restore executions.
  - This api is used to get the execution detail of a specific backup or restore worflow process.
version_added: '6.18.0'
extends_documentation_fragment:
  - cisco.dnac.module_info
author: Rafael Campos (@racampos)
options:
  headers:
    description: Additional headers.
    type: dict
  backupId:
    description:
      - >
        BackupId query parameter. The `backupId` of the backup execution to be retrieved.Obtain the `backupId`
        from the id attribute in the response of the `/dna/system/api/v1/backups` API.
    type: str
  jobType:
    description:
      - >
        JobType query parameter. Execution type of the backup workflow. If the workflow is `Create Backup` The
        jobType is `CREATE_BACKUP`. If the workflow is `Delete Backup` The jobType is `DELETE_BACKUP`. If the
        workflow is `Restore Backup` The jobType is `RESTORE_BACKUP`.
    type: str
  status:
    description:
      - >
        Status query parameter. Execution status of the workflow.If the workflow execution has started, the
        status is `IN_PROGRESS`.If the workflow execution has completed, the status is `SUCCESS`.If the workflow
        execution has failed, the status is `FAILED`.
    type: str
  offset:
    description:
      - Offset query parameter. The first record to show for this page.
    type: int
  limit:
    description:
      - Limit query parameter. The number of records to show for this page.
    type: int
  sortBy:
    description:
      - SortBy query parameter. A property within the response to sort by.
    type: str
  order:
    description:
      - >
        Order query parameter. Whether ascending or descending order should be used to sort the response.Use
        `asc` for ascending and `desc` for descending order .
    type: str
  id:
    description:
      - Id path parameter. The `id` of the backup execution to be retrieved.
    type: str
requirements:
  - dnacentersdk >= 2.11.0
  - python >= 3.12
seealso:
  - name: Cisco DNA Center documentation for Backup GetBackupAndRestoreExecution
    description: Complete reference of the GetBackupAndRestoreExecution API.
    link: https://developer.cisco.com/docs/dna-center/#!get-backup-and-restore-execution
  - name: Cisco DNA Center documentation for Backup GetBackupAndRestoreExecutions
    description: Complete reference of the GetBackupAndRestoreExecutions API.
    link: https://developer.cisco.com/docs/dna-center/#!get-backup-and-restore-executions
notes:
  - SDK Method used are
    backup.Backup.get_backup_and_restore_execution,
    backup.Backup.get_backup_and_restore_executions,
  - Paths used are
    get /dna/system/api/v1/backupRestoreExecutions,
    get /dna/system/api/v1/backupRestoreExecutions/{id},
"""

EXAMPLES = r"""
---
- name: Get all Backup Restore Executions
  cisco.dnac.backup_restore_executions_info:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    headers: "{{my_headers | from_json}}"
    backupId: string
    jobType: string
    status: string
    offset: 0
    limit: 0
    sortBy: string
    order: string
  register: result
- name: Get Backup Restore Executions by id
  cisco.dnac.backup_restore_executions_info:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    headers: "{{my_headers | from_json}}"
    id: string
  register: result
"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {
      "response": {
        "_metadata": {},
        "backupId": "string",
        "completedPercentage": 0,
        "createdBy": "string",
        "duration": 0,
        "endDate": "string",
        "errorCode": "string",
        "errorMessage": "string",
        "failedTaskDetail": {},
        "id": "string",
        "isForceUpdate": true,
        "jobType": "string",
        "scope": "string",
        "startDate": "string",
        "status": "string",
        "systemErrorMessage": "string",
        "tasks": [
          {
            "endDate": "string",
            "errorCode": "string",
            "failedTaskDetail": {},
            "id": "string",
            "message": "string",
            "startDate": "string",
            "status": "string",
            "systemErrorMessage": "string",
            "taskName": "string"
          }
        ],
        "updateMessage": "string"
      },
      "version": "string"
    }
"""



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
module: devices_switch_ports_info
short_description: Information module for devices _switch _ports
description:
  - Information module for Devices Switch Ports Info.
  - Get all devices _switch _ports.
  - Get devices _switch _ports by id.
  - List the switch ports for a switch.
  - Return a switch port.
version_added: '1.0.0'
extends_documentation_fragment:
  - cisco.meraki.module_info
author: Francisco Munoz (@fmunoz)
options:
  headers:
    description: Additional headers.
    type: dict
  serial:
    description:
      - Information module for Devices Switch Ports Info.
      - Serial path parameter.
    type: str
  portId:
    description:
      - Information module for Devices Switch Ports Info.
      - PortId path parameter. Port ID.
    type: str
requirements:
  - meraki >= 2.4.9
  - python >= 3.5
seealso:
  - name: Cisco Meraki documentation for switch getDeviceSwitchPort
    description: Complete reference of the getDeviceSwitchPort API.
    link: https://developer.cisco.com/meraki/api-v1/#!get-device-switch-port
  - name: Cisco Meraki documentation for switch getDeviceSwitchPorts
    description: Complete reference of the getDeviceSwitchPorts API.
    link: https://developer.cisco.com/meraki/api-v1/#!get-device-switch-ports
notes:
  - SDK Method used are
    switch.Switch.get_device_switch_port,
    switch.Switch.get_device_switch_ports,
  - Paths used are
    get /devices/{serial}/switch/ports,
    get /devices/{serial}/switch/ports/{portId},
"""

EXAMPLES = r"""
- name: Get all devices _switch _ports
  cisco.meraki.devices_switch_ports_info:
    meraki_api_key: "{{ meraki_api_key }}"
    meraki_base_url: "{{ meraki_base_url }}"
    meraki_single_request_timeout: "{{ meraki_single_request_timeout }}"
    meraki_certificate_path: "{{ meraki_certificate_path }}"
    meraki_requests_proxy: "{{ meraki_requests_proxy }}"
    meraki_wait_on_rate_limit: "{{ meraki_wait_on_rate_limit }}"
    meraki_nginx_429_retry_wait_time: "{{ meraki_nginx_429_retry_wait_time }}"
    meraki_action_batch_retry_wait_time: "{{ meraki_action_batch_retry_wait_time }}"
    meraki_retry_4xx_error: "{{ meraki_retry_4xx_error }}"
    meraki_retry_4xx_error_wait_time: "{{ meraki_retry_4xx_error_wait_time }}"
    meraki_maximum_retries: "{{ meraki_maximum_retries }}"
    meraki_output_log: "{{ meraki_output_log }}"
    meraki_log_file_prefix: "{{ meraki_log_file_prefix }}"
    meraki_log_path: "{{ meraki_log_path }}"
    meraki_print_console: "{{ meraki_print_console }}"
    meraki_suppress_logging: "{{ meraki_suppress_logging }}"
    meraki_simulate: "{{ meraki_simulate }}"
    meraki_be_geo_id: "{{ meraki_be_geo_id }}"
    meraki_caller: "{{ meraki_caller }}"
    meraki_use_iterator_for_get_pages: "{{ meraki_use_iterator_for_get_pages }}"
    meraki_inherit_logging_config: "{{ meraki_inherit_logging_config }}"
    serial: string
  register: result
- name: Get devices _switch _ports by id
  cisco.meraki.devices_switch_ports_info:
    meraki_api_key: "{{ meraki_api_key }}"
    meraki_base_url: "{{ meraki_base_url }}"
    meraki_single_request_timeout: "{{ meraki_single_request_timeout }}"
    meraki_certificate_path: "{{ meraki_certificate_path }}"
    meraki_requests_proxy: "{{ meraki_requests_proxy }}"
    meraki_wait_on_rate_limit: "{{ meraki_wait_on_rate_limit }}"
    meraki_nginx_429_retry_wait_time: "{{ meraki_nginx_429_retry_wait_time }}"
    meraki_action_batch_retry_wait_time: "{{ meraki_action_batch_retry_wait_time }}"
    meraki_retry_4xx_error: "{{ meraki_retry_4xx_error }}"
    meraki_retry_4xx_error_wait_time: "{{ meraki_retry_4xx_error_wait_time }}"
    meraki_maximum_retries: "{{ meraki_maximum_retries }}"
    meraki_output_log: "{{ meraki_output_log }}"
    meraki_log_file_prefix: "{{ meraki_log_file_prefix }}"
    meraki_log_path: "{{ meraki_log_path }}"
    meraki_print_console: "{{ meraki_print_console }}"
    meraki_suppress_logging: "{{ meraki_suppress_logging }}"
    meraki_simulate: "{{ meraki_simulate }}"
    meraki_be_geo_id: "{{ meraki_be_geo_id }}"
    meraki_caller: "{{ meraki_caller }}"
    meraki_use_iterator_for_get_pages: "{{ meraki_use_iterator_for_get_pages }}"
    meraki_inherit_logging_config: "{{ meraki_inherit_logging_config }}"
    serial: string
    portId: string
  register: result
"""
RETURN = r"""
meraki_response:
  description: A dictionary or list with the response returned by the Cisco Meraki Python SDK
  returned: always
  type: dict
  sample: >
    {
      "portId": "string",
      "name": "string",
      "tags": [
        "string"
      ],
      "enabled": true,
      "poeEnabled": true,
      "type": "string",
      "vlan": 0,
      "voiceVlan": 0,
      "allowedVlans": "string",
      "isolationEnabled": true,
      "rstpEnabled": true,
      "stpGuard": "string",
      "stpPortFastTrunk": true,
      "linkNegotiation": "string",
      "linkNegotiationCapabilities": [
        "string"
      ],
      "portScheduleId": "string",
      "schedule": {
        "id": "string",
        "name": "string"
      },
      "udld": "string",
      "accessPolicyType": "string",
      "accessPolicyNumber": 0,
      "macAllowList": [
        "string"
      ],
      "macWhitelistLimit": 0,
      "stickyMacAllowList": [
        "string"
      ],
      "stickyMacAllowListLimit": 0,
      "stormControlEnabled": true,
      "adaptivePolicyGroupId": "string",
      "adaptivePolicyGroup": {
        "id": "string",
        "name": "string"
      },
      "peerSgtCapable": true,
      "flexibleStackingEnabled": true,
      "daiTrusted": true,
      "profile": {
        "enabled": true,
        "id": "string",
        "iname": "string"
      },
      "module": {
        "model": "string",
        "serial": "string",
        "slot": 0
      },
      "mirror": {
        "mode": "string"
      },
      "dot3az": {
        "enabled": true
      },
      "highSpeed": {
        "enabled": true
      }
    }
"""
